![Wagtail Content Import](docs/img/wagtail_content_import_logo_with_text.svg)

Wagtail Content Import is a module for importing page content into Wagtail from third-party sources. 
Page content is imported into a StreamField, using a set of customisable mappings.
Currently supports:

### As sources:
- Google Docs
- OneDrive/SharePoint

### As files:
- Google Docs documents with:
    - Rich text
    - Tables
    - Images
    - Headings
- Docx files with:
    - Text with bold and italics
    - Headings

### Requirements:
* Django 2.2
* Wagtail 2.2

For the full documentation, see: https://torchbox.github.io/wagtail-content-import/
